@@ -1,9 +1,9 @@
 /***********************************************************************
  @C-file{
     author              = "Nelson H. F. Beebe",
-    version             = "0.08",
-    date                = "29 November 1994",
-    time                = "12:09:37 MST",
+    version             = "0.10",
+    date                = "22 April 2000",
+    time                = "13:12:52 MDT",
     filename            = "bibcheck.c",
     address             = "Center for Scientific Computing
 			   Department of Mathematics
@@ -12,8 +12,9 @@
 			   USA",
     telephone           = "+1 801 581 5254",
     FAX                 = "+1 801 581 4148",
-    checksum            = "20052 1348 3228 29026",
+    checksum            = "36188 1372 3378 31386",
     email               = "beebe@math.utah.edu (Internet)",
+    URL                 = "http://www.math.utah.edu/~beebe/",
     codetable           = "ISO/ASCII",
     keywords            = "BibTeX, pattern matching, syntax checking",
     supported           = "yes",
@@ -71,29 +72,15 @@
 }
 ***********************************************************************/
 
-#define BIBCHECK_VERSION	"bibcheck Version 0.08 [29-Nov-1994]"
+#define BIBCHECK_VERSION	"bibcheck Version 0.10 [22-Apr-2000]"
 
-#include "os.h"
+#include <config.h>
 #include "xstring.h"
 #include "xstdlib.h"
 #include "xctype.h"
 #include "hash.h"
 #include "regexp/regexp.h"
 
-#if defined(M_I86)
-#define CONST		/* bug workaround for IBM PC Microsoft C compilers */
-#else /* NOT M_I86 */
-#define CONST const
-#endif /* M_I86 */
-
-#define NEW_STYLE	STDC
-
-#if NEW_STYLE
-#define VOID		void
-#else
-#define VOID
-#endif
-
 #ifdef MAX
 #undef MAX
 #endif
@@ -104,10 +91,9 @@
 #define ISDIGIT(c)	isdigit(BYTE_VAL(c))
 #define ISPRINT(c)	isprint(BYTE_VAL(c)) /* ensure arg in 0..255 */
 #define ISSPACE(c)	isspace(BYTE_VAL(c))
-#define STREQUAL(s,t)	(strcmp((s),(t)) == 0)
-#define output(c)	(void)fputc(c,stdout)
+#define output(c)	(void)fputc((int)(c),stdout)
 
-#if NEW_STYLE
+#if defined(HAVE_STDC)
 typedef enum token_list {
     TOKEN_UNKNOWN = 0,
     TOKEN_ABBREV = 1,		/* alphabetical order, starting at 1 */
@@ -130,7 +116,7 @@ typedef enum token_list {
     TOKEN_STRING,
     TOKEN_VALUE
 } token_t;
-#else /* K&R style */
+#else
 typedef int token_t;
 #define	TOKEN_UNKNOWN	0
 #define	TOKEN_ABBREV	1		/* alphabetical order, starting at 1 */
@@ -152,7 +138,7 @@ typedef int token_t;
 #define	TOKEN_SPACE	17
 #define	TOKEN_STRING	18
 #define	TOKEN_VALUE	19
-#endif /* NEW_STYLE */
+#endif
 
 static const char *type_name[] =
 {				/* must be indexable by TOKEN_xxx */
@@ -208,7 +194,7 @@ extern const char	*the_filename;
 extern char		yytext[];
 
 #ifndef YYLMAX
-#define YYLMAX		40960
+#define YYLMAX		32512
 #endif
 
 static HASH_TABLE	*abbrev_table;
@@ -279,22 +265,26 @@ static void		tie ARGS((void));
 static void		trailing_blank ARGS((void));
 static void		warning ARGS((const char *s_));
 
+#if defined(HAVE_FLEX)
+int			yylex ARGS((void));
+#else
 #if (__hppa || _IBMR2 || __sgi || __solaris || sun) && defined(__cplusplus)
 /* Most C++ compilers assume that yylex() is a C function instead of a C++ function */
 extern "C" int		yylex ARGS((void));
 #else
 int			yylex ARGS((void));
 #endif
+#endif
 
-#if NEW_STYLE
+#if defined(HAVE_STDC)
 int
 main(int argc, char* argv[])
-#else /* old K&R style */
+#else
 int
 main(argc,argv)
 int argc;
 char* argv[];
-#endif /* NEW_STYLE */
+#endif
 {
     FILE *fp;
     int k;
@@ -309,43 +299,48 @@ char* argv[];
     {
 	for (k = 1; k < argc; ++k)
 	{
-	    if (ARGEQUAL(argv[k],"-author",2))
+	    char *the_arg;
+
+	    the_arg = argv[k];
+	    if ((the_arg[0] == '-') && (the_arg[1] == '-'))
+		the_arg++;
+	    if (ARGEQUAL(the_arg,"-author",2))
 	    {
 		opt_author();
-		continue;
+		exit(EXIT_SUCCESS);
 	    }
-	    else if (ARGEQUAL(argv[k],"-copyright",2))
+	    else if (ARGEQUAL(the_arg,"-copyright",2))
 	    {
 		opt_copyright();
-		continue;
+		exit(EXIT_SUCCESS);
 	    }
-	    else if (ARGEQUAL(argv[k],"-debug",2))
+	    else if (ARGEQUAL(the_arg,"-debug",2))
 	    {
 		debug = 1;
 		continue;
 	    }
-	    else if (ARGEQUAL(argv[k],"-help",2))
+	    else if (ARGEQUAL(the_arg,"-help",2))
 	    {
 		opt_usage();
-		continue;
+		exit(EXIT_SUCCESS);
 	    }
-	    else if (ARGEQUAL(argv[k],"-version",2))
+	    else if (ARGEQUAL(the_arg,"-version",2))
 	    {
 		opt_version();
-		continue;
+		exit(EXIT_SUCCESS);
 	    }
-	    fp = freopen(argv[k],"r",stdin);
+	    fp = freopen(the_arg,"r",stdin);
 	    nfiles++;
 	    if (fp == (FILE*)NULL)
 	    {
 		(void)fprintf(stderr,
 		    "\n%s Ignoring open failure on file [%s]\n",
-		    ERROR_PREFIX, argv[k]);
+		    ERROR_PREFIX, the_arg);
 		(void)perror("perror() says");
 	    }
 	    else
 	    {
-		the_filename = (const char*)argv[k];
+		the_filename = (const char*)the_arg;
 		dolex();
 		(void)fclose(fp);
 	    }
@@ -431,7 +426,7 @@ dolex(VOID)
     }
 }
 
-#if NEW_STYLE
+#if defined(HAVE_STDC)
 static void
 add_keyword(const char *name)
 #else
@@ -557,7 +552,7 @@ compact_space(VOID) /* compact runs of space to single blank */
     *q = '\0';
 }
 
-#if NEW_STYLE
+#if defined(HAVE_STDC)
 static void
 delete_table_entries(HASH_TABLE *table)
 #else
@@ -573,12 +568,12 @@ HASH_TABLE *table;
     {
 	if (h->hash_key != (const char *)NULL)
 	{
-	    free((VOIDP)h->hash_key);
+	    FREE(h->hash_key);
 	    h->hash_key = (const char *)NULL;
 	}
 	if (h->hash_data != (VOIDP)NULL)
 	{
-	    free(h->hash_data);
+	    FREE(h->hash_data);
 	    h->hash_data = (VOIDP)NULL;
 	}
     }
@@ -716,7 +711,7 @@ end_entry(VOID)
     delete_table_entries(keyword_table);
 }
 
-#if NEW_STYLE
+#if defined(HAVE_STDC)
 static HASH_TABLE*
 enlarge_table(HASH_TABLE *table)
 #else
@@ -759,7 +754,7 @@ HASH_TABLE *table;
     return (new_table);
 }
 
-#if NEW_STYLE
+#if defined(HAVE_STDC)
 static void
 error(const char *message)
 #else
@@ -777,7 +772,7 @@ const char *message;
     exit(EXIT_FAILURE);
 }
 
-#if NEW_STYLE
+#if defined(HAVE_STDC)
 static void
 free_table(HASH_TABLE *table)
 #else
@@ -796,7 +791,7 @@ initials(VOID)
     warning("adjacent dotted initials perhaps need a space");
 }
 
-#if NEW_STYLE
+#if defined(HAVE_STDC)
 static int
 in_table(const char *key, HASH_TABLE *table)
 #else
@@ -812,7 +807,7 @@ HASH_TABLE *table;
     return ((h != (HASH_ENTRY*)NULL) && (h->hash_key != (const char*)NULL));
 }
 
-#if NEW_STYLE
+#if defined(HAVE_STDC)
 static void
 install(const char *key, const char *value, HASH_TABLE **ptable)
 #else
@@ -836,12 +831,12 @@ HASH_TABLE **ptable;
 	    (void)strcpy((char *)h->hash_key, key);
 	else
 	{
-	    free((VOIDP)h->hash_key);
-	    h->hash_key = STRDUP(key);
+	    FREE(h->hash_key);
+	    h->hash_key = Strdup(key);
 	}
     }
     else
-	h->hash_key = STRDUP(key);
+	h->hash_key = Strdup(key);
 
     if (h->hash_data != (VOIDP)NULL)
     {
@@ -849,15 +844,15 @@ HASH_TABLE **ptable;
 	    (void)strcpy((char *)h->hash_data, value);
 	else
 	{
-	    free((VOIDP)h->hash_data);
-	    h->hash_data = (VOIDP)STRDUP(value);
+	    FREE(h->hash_data);
+	    h->hash_data = (VOIDP)Strdup(value);
 	}
     }
     else
-	h->hash_data = (VOIDP)STRDUP(value);
+	h->hash_data = (VOIDP)Strdup(value);
 }
 
-#if NEW_STYLE
+#if defined(HAVE_STDC)
 static const char*
 lookup(const char *key, HASH_TABLE *table)
 #else
@@ -878,7 +873,7 @@ HASH_TABLE *table;
 	return ((const char*)h->hash_data);
 }
 
-#if NEW_STYLE
+#if defined(HAVE_STDC)
 static char *
 lower(char *s)
 #else
@@ -897,7 +892,7 @@ char *s;
     return (s);
 }
 
-#if NEW_STYLE
+#if defined(HAVE_STDC)
 static HASH_TABLE*
 make_hash_table(HASH_INT size)
 #else
@@ -919,15 +914,15 @@ HASH_INT size;
     return (table);
 }
 
-#if NEW_STYLE
+#if defined(HAVE_STDC)
 static int
 match(REGEXP_ENTRY *r, const char *s)
-#else /* K&R style */
+#else
 static int
 match(r,s)
 REGEXP_ENTRY *r;
 const char *s;
-#endif /* NEW_STYLE */
+#endif
 {
     int		result;
     char	msg[MAX_MSG];
@@ -1043,10 +1038,11 @@ opt_author(VOID)
 	"\tTel: +1 801 581 5254\n",
 	"\tFAX: +1 801 581 4801\n",
 	"\tEmail: <beebe@math.utah.edu>\n",
+	"\tWWW URL: http://www.math.utah.edu/~beebe\n",
 	(const char*)NULL,
     };
 
-    out_lines(stdout, author_text);
+    out_lines(stderr, author_text);
 }
 
 static void
@@ -1054,14 +1050,42 @@ opt_copyright(VOID)
 {
     static CONST char *copyright_text[] =
     {
-	"*********************************************\n",
-	"*********************************************\n",
-	"*** This program is in the PUBLIC DOMAIN. ***\n",
-	"*********************************************\n",
-	"*********************************************\n",
+	"########################################################################\n",
+	"########################################################################\n",
+	"########################################################################\n",
+	"###                                                                  ###\n",
+	"###             bibcheck: check a BibTeX bibliography file           ###\n",
+	"###                                                                  ###\n",
+	"###              Copyright (C) 2000 Nelson H. F. Beebe               ###\n",
+	"###                                                                  ###\n",
+	"### This program is covered by the GNU General Public License (GPL), ###\n",
+	"### version 2 or later, available as the file COPYING in the program ###\n",
+	"### source distribution, and on the Internet at                      ###\n",
+	"###                                                                  ###\n",
+	"###               ftp://ftp.gnu.org/gnu/GPL                          ###\n",
+	"###                                                                  ###\n",
+	"###               http://www.gnu.org/copyleft/gpl.html               ###\n",
+	"###                                                                  ###\n",
+	"### This program is free software; you can redistribute it and/or    ###\n",
+	"### modify it under the terms of the GNU General Public License as   ###\n",
+	"### published by the Free Software Foundation; either version 2 of   ###\n",
+	"### the License, or (at your option) any later version.              ###\n",
+	"###                                                                  ###\n",
+	"### This program is distributed in the hope that it will be useful,  ###\n",
+	"### but WITHOUT ANY WARRANTY; without even the implied warranty of   ###\n",
+	"### MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    ###\n",
+	"### GNU General Public License for more details.                     ###\n",
+	"###                                                                  ###\n",
+	"### You should have received a copy of the GNU General Public        ###\n",
+	"### License along with this program; if not, write to the Free       ###\n",
+	"### Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   ###\n",
+	"### MA 02111-1307 USA                                                ###\n",
+	"########################################################################\n",
+	"########################################################################\n",
+	"########################################################################\n",
 	(const char*)NULL,
     };
-    out_lines(stdout, copyright_text);
+    out_lines(stderr, copyright_text);
 }
 
 static void
@@ -1074,7 +1098,7 @@ opt_usage(VOID)
 	"is ignored.\n",
 	(const char*)NULL,
     };
-    out_lines(stdout, usage_text);
+    out_lines(stderr, usage_text);
 }
 
 static void
@@ -1086,18 +1110,18 @@ opt_version(VOID)
 	"\n",
 	(const char*)NULL,
     };
-    out_lines(stdout, version_text);
+    out_lines(stderr, version_text);
 }
 
-#if NEW_STYLE
+#if defined(HAVE_STDC)
 static void
 out_lines(FILE *fpout, const char *lines[])
-#else /* K&R style */
+#else
 static void
 out_lines(fpout, lines)
 FILE *fpout;
 const char *lines[];
-#endif /* NEW_STYLE */
+#endif
 {
     int	k;
 
@@ -1105,14 +1129,14 @@ const char *lines[];
 	(void)fputs(lines[k], fpout);
 }
 
-#if NEW_STYLE
+#if defined(HAVE_STDC)
 static token_t
 out_protected_string(token_t t)
-#else /* K&R style */
+#else
 static token_t
 out_protected_string(t)
 token_t t;
-#endif /* NEW_STYLE */
+#endif
 {
     char	octal[4 + 1];
     const char	*token = (const char*)&yytext[0];
@@ -1182,14 +1206,14 @@ token_t t;
     return (TOKEN_VALUE);
 }
 
-#if NEW_STYLE
+#if defined(HAVE_STDC)
 static token_t
 out_token(token_t t)
 #else
 static token_t
 out_token(t)
 token_t t;
-#endif /* NEW_STYLE */
+#endif
 {		/* ALL token output is directed through this function */
     int	n;
 
@@ -1248,7 +1272,7 @@ token_t t;
 }
 
 static void
-overflow()
+overflow(VOID)
 {
     char	msg[MAX_MSG];
 
@@ -1267,7 +1291,7 @@ pages(VOID)
 }
 
 static void
-page_range()
+page_range(VOID)
 {
     warning("hyphen found where en-dash expected");
     end_blank();
@@ -1316,7 +1340,7 @@ trailing_blank(VOID)
     warning("trailing space");
 }
 
-#if NEW_STYLE
+#if defined(HAVE_STDC)
 static void
 warning(const char *message)
 #else
